<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="AddAttribute">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete"
                     style="margin-left: 10px">删除
          </el-button>
        </el-popconfirm>
      </div>
      <el-table border size="mini" :data="tableData" :height="tableMaxHeight" :style="{width: '100%'}"
                :cell-style="{'text-align': 'center'}" :header-cell-style="{'text-align': 'center'}"
                @row-dblclick="handleDbClick" @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column type="index" width="55" label="序号"></el-table-column>
        <el-table-column  prop="warnName" label="告警名称"></el-table-column>
        <el-table-column  prop="createTime" label="创建时间"></el-table-column>
        <el-table-column  prop="memo" label="备注"></el-table-column>
      </el-table>
      <el-pagination align="right" background ref="paginationPanel" @size-change="handleSizeChange"
                     @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
                     :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
                     layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <AlarmConfigurationDialog ref="formModal" :productId="productIds" @reload="loadData"></AlarmConfigurationDialog>
  </div>
</template>

<script>
import {
  TableMixin
} from '@/mixins/tableMixin'
import PhysicalModel from '@/api/device/PhysicalModel.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import AlarmConfigurationDialog from './AlarmConfigurationDialog.vue'

export default {
  props: {
    parameter: {
      type: Object,
      default: function() {
        return
      }
    }
  },
  mixins: [TableMixin],
  components: {
    AlarmConfigurationDialog
  },
  data() {
    return {
      url: {
        delete: '/device/product/warnConf/'
      },
      productIds: '',
      typeList: [], //事件等级
      outDataFormartList: [], //参数格式
      outDataTypeList: [], //参数类型
      sortList: {}
    }
  },
  created() {
    this.productIds = this.parameter.id
  },
  methods: {
    AddAttribute() {
      this.$refs.formModal.add()
    },
    loadData(page) {
      this.loading = true
      this.queryParam.querys = [{
        group: 'main',
        operation: 'EQUAL',
        parentGroup: '',
        property: 'productId',
        relation: 'AND',
        value: this.parameter.id
      }]
      PhysicalModel.loadAlerts(this.queryParam, res => {
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    insort(val) {
      let id = val.id
      let value = val.sn
      this.sortList[id] = value
    }
  }
}
</script>

<style lang="scss" scoped>
::v-deep .bbsl-table-content {
  box-shadow: 0px 0px 0 0;
  margin-top: 0px;
  padding: 0px;
}

::v-deep .el-table {
  height: 100% !important;
}
</style>
